@@ -35,27 +35,26 @@
 
 import importlib
 import os.path
+from collections.abc import Iterator
 from glob import glob
-from typing import Dict, Iterator, List  # noqa: F401
 
 
 class Plugin(type):
     """Meta class for plugins."""
 
     def __new__(mcs, name, bases, attrs):
-        new_cls = super(Plugin, mcs).__new__(mcs, name, bases, attrs)
+        new_cls = super().__new__(mcs, name, bases, attrs)
         Plugins.add_plugin(new_cls)
         return new_cls
 
 
-class Plugins(object):
+class Plugins:
     """Register `Plugin` subclasses and iterate over them."""
 
-    _plugins = []  # type: List[Plugin]
-    _imported = {}  # type: Dict[str, bool]
+    _plugins: list[Plugin] = []
+    _imported: dict[str, bool] = {}
 
-    def __init__(self, python_path):
-        # type: (str) -> None
+    def __init__(self, python_path: str) -> None:
         """
         :param str python_path: fully dotted Python path that the plugins will
                 be found below
@@ -64,8 +63,7 @@ class Plugins(object):
         self._imported.setdefault(python_path, False)
 
     @classmethod
-    def add_plugin(cls, plugin):
-        # type: (Plugin) -> None
+    def add_plugin(cls, plugin: Plugin) -> None:
         """
         Called by `Plugin` meta class to register a new `Plugin` subclass.
 
@@ -73,8 +71,7 @@ class Plugins(object):
         """
         cls._plugins.append(plugin)
 
-    def __iter__(self):
-        # type: () -> Iterator[Plugin]
+    def __iter__(self) -> Iterator[Plugin]:
         """
         Iterator for registered `Plugin` subclasses.
 
@@ -86,8 +83,7 @@ class Plugins(object):
             if plugin.__module__.startswith(self.python_path):
                 yield plugin
 
-    def load(self):
-        # type: () -> None
+    def load(self) -> None:
         """Load plugins."""
         if self._imported.get(self.python_path):
             return
@@ -101,13 +97,11 @@ class Plugins(object):
         self._imported[self.python_path] = True
 
 
-def get_all_dynamic_classes():
-    # type: () -> Iterator[Plugin]
+def get_all_dynamic_classes() -> Iterator[Plugin]:
     yield from Plugins("univention.portal.extensions")
 
 
-def get_dynamic_classes(klass_name):
-    # type: (str) -> Plugin
+def get_dynamic_classes(klass_name: str) -> Plugin:
     for extension in get_all_dynamic_classes():
         if klass_name == extension.__name__:
             return extension
