@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -146,11 +145,11 @@ layout = [
 
 
 def mapTranslationValue(vals, encoding=()):
-    return [u' '.join(val).encode(*encoding) for val in vals]
+    return [' '.join(val).encode(*encoding) for val in vals]
 
 
 def unmapTranslationValue(vals, encoding=()):
-    return [val.decode(*encoding).split(u' ', 1) for val in vals]
+    return [val.decode(*encoding).split(' ', 1) for val in vals]
 
 
 mapping = univention.admin.mapping.mapping()
